// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

/// A mixin that provides implementation of helper methods for
/// bloc and cubit [B] widgets.
mixin BlocBaseProviderMixin<B extends BlocBase<Object>> {
  /// Returns the [BlocBase] used by this [BlocBaseProviderMixin].
  B bloc(BuildContext context) => context.read<B>();

  /// Returns another [BlocBase] **not** used by this [BlocBaseProviderMixin].
  /// Short hand for `context.read<AnotherBloc>();`
  ///
  /// To get [BlocBase] used by by this [BlocBaseProviderMixin] see `bloc()`
  AnotherBloc anotherBloc<AnotherBloc>(BuildContext context) =>
      context.read<AnotherBloc>();
}
