// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:args/args.dart';
import 'package:wyatt_continuous_deployment/src/core/utils/logging.dart';

enum Flag {
  verbose('v'),
  force('f');

  const Flag(this.abbr);

  final String abbr;

  static List<Flag> fromArgs({
    required ArgResults results,
    required ArgResults globalResults,
  }) {
    final flags = <Flag>[];

    for (final flag in Flag.values) {
      if (results.options.contains(flag.name)) {
        logger.detail('Flag: ${flag.name} was parsed in results');
        if (results[flag.name] as bool) {
          flags.add(flag);
        }
      } else if (globalResults.options.contains(flag.name)) {
        logger.detail('Flag: ${flag.name} was parsed in globalResults');
        if (globalResults[flag.name] as bool) {
          flags.add(flag);
        }
      }
    }

    return flags;
  }
}
