// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';
import 'dart:io';

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_continuous_deployment/src/core/injection/injectable.dart';
import 'package:wyatt_continuous_deployment/src/core/utils/logging.dart';
import 'package:wyatt_type_utils/wyatt_type_utils.dart';

@usecase
class FindLastIpaFileUsecase extends AsyncUseCase<String, String> {
  const FindLastIpaFileUsecase() : super();

  @override
  FutureOr<void> onStart(String? params) {
    if (params == null) {
      throw const ClientException(
        'FindLastIpaFileUsecase: You must provide a path',
      );
    }
  }

  @override
  FutureOrResult<String> execute(String? params) {
    final Directory directory = Directory(params!);

    if (!directory.existsSync()) {
      logger.detail('No IPA file found in $params');
      return Err(ClientException('Directory not found: $params'));
    }

    final List<FileSystemEntity> files = directory.listSync()
      ..sort((a, b) => b.statSync().modified.compareTo(a.statSync().modified));

    for (final FileSystemEntity file in files) {
      if (file.path.endsWith('.ipa')) {
        logger.detail('Found IPA file: ${file.path}');
        return Ok(file.path);
      }
    }

    logger.detail('No IPA file found in $params');
    return Err(ClientException('No IPA file found in $params'));
  }
}
