// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

class TopBarThemeExtensionDefault extends TopBarThemeExtension {
  const TopBarThemeExtensionDefault({
    required super.iconTheme,
    required super.backgroundColors,
    required super.titleStyle,
    required super.subtitleStyle,
    required super.selectedIndicatorColors,
    required super.selectedIndicatorSize,
    required super.dividerColor,
  });

  /// Creates a [TopBarThemeExtensionDefault] from a [ThemeData]
  /// and opinionated defaults.
  ///
  /// {@macro card_theme_extension_default}
  factory TopBarThemeExtensionDefault.from(ThemeData theme) =>
      TopBarThemeExtensionDefault(
        backgroundColors: MultiColor.single(theme.appBarTheme.backgroundColor),
        titleStyle:
            theme.appBarTheme.titleTextStyle ?? theme.textTheme.titleMedium,
        subtitleStyle: theme.textTheme.bodyMedium,
        selectedIndicatorColors: MultiColor.single(theme.colorScheme.primary),
        selectedIndicatorSize: const Size(70, 5),
        iconTheme: theme.iconTheme,
        dividerColor: theme.colorScheme.onSurface.withOpacity(0.12),
      );

  /// Creates a [TopBarThemeExtensionDefault] from a dark [ThemeData]
  factory TopBarThemeExtensionDefault.dark() =>
      TopBarThemeExtensionDefault.from(ThemeData.dark());

  /// Creates a [TopBarThemeExtensionDefault] from a light [ThemeData]
  factory TopBarThemeExtensionDefault.light() =>
      TopBarThemeExtensionDefault.from(ThemeData.light());
}
